"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.print = exports.prettyPrint = void 0;

require("core-js/modules/es6.array.from");

var _markedTerminal = _interopRequireDefault(require("marked-terminal"));

var _chalk = _interopRequireDefault(require("chalk"));

var _marked = _interopRequireDefault(require("marked"));

var _clipboardy = require("clipboardy");

var _cliHighlight = require("cli-highlight");

var _helpers = require("./helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_marked.default.setOptions({
  renderer: new _markedTerminal.default()
});

const prettyPrint = x => {
  const printMap = {
    code: y => (0, _cliHighlight.highlight)(y.code, {
      language: 'javascript'
    }),
    description: y => (0, _helpers.enforceSingleNewLine)((0, _marked.default)(y.description)),
    example: y => (0, _cliHighlight.highlight)(y.example, {
      language: 'javascript'
    }),
    id: y => [_chalk.default.magenta.bold(y.id), _chalk.default.magenta.bold('-'.repeat(y.id.length))].join('\n')
  };
  return x.map(y => Object.keys(y).map(k => printMap[k](y) + (k === 'id' ? '' : '\n')).join('\n').replace(/\n$/, '')).join('\n\n');
};

exports.prettyPrint = prettyPrint;

const print = ({
  cp,
  layout,
  json
}, x) => {
  const arr = Array.isArray(x) ? x : [x];
  const layoutMap = {
    c: 'code',
    d: 'description',
    e: 'example',
    i: 'id'
  };
  const layoutKeys = Array.from(layout).map(k => layoutMap[k]);

  if (cp) {
    (0, _clipboardy.writeSync)(arr.map(y => y.code).join('\n'));
  }

  if (json) {
    console.log(JSON.stringify(arr.map(y => (0, _helpers.pick)(y, layoutKeys))));
  } else {
    console.log(prettyPrint(arr.map(y => (0, _helpers.pick)(y, layoutKeys))));
  }
};

exports.print = print;